import { Jwt, JwtAdditionalOptions, JwtOptions, JwtVerificationResult } from '../jwt';
import { SignatureAndEncryptionAlgorithm } from '../signatureAndEncryptionAlgorithm';
import { MakePropertyRequired, Signer, Verifier } from '../types';
type ReturnKeyBindingWithHeaderAndPayload<H extends Record<string, unknown>, P extends Record<string, unknown>, T extends KeyBinding<H, P>> = MakePropertyRequired<T, 'header' | 'payload'>;
export type KeyBindingHeader<H extends Record<string, unknown> = Record<string, unknown>> = H & {
    typ: 'kb+jwt';
    alg: SignatureAndEncryptionAlgorithm | string;
};
export type KeyBindingPayload<P extends Record<string, unknown> = Record<string, unknown>> = P & {
    iat: number;
    aud: string;
    nonce: string;
};
export type KeyBindingOptions<Header extends Record<string, unknown> = Record<string, unknown>, Payload extends Record<string, unknown> = Record<string, unknown>> = JwtOptions<KeyBindingHeader<Header>, KeyBindingPayload<Payload>>;
export type KeyBindingAdditionalOptions<Header extends Record<string, unknown> = Record<string, unknown>> = JwtAdditionalOptions<KeyBindingHeader<Header>>;
export type KeyBindingVerificationResult = JwtVerificationResult;
export declare class KeyBinding<Header extends Record<string, unknown> = Record<string, unknown>, Payload extends Record<string, unknown> = Record<string, unknown>> extends Jwt<Header, Payload> {
    signer?: Signer<Header>;
    constructor(options?: KeyBindingOptions<Header, Payload>, additionalOptions?: KeyBindingAdditionalOptions<Header>);
    /**
     *
     * Convert a standard `JWT` to an instance of `KeyBinding`.
     *
     * @throws when the claims are not valid for key binding
     *
     */
    static fromJwt<Header extends Record<string, unknown> = Record<string, unknown>, Payload extends Record<string, unknown> = Record<string, unknown>>(jwt: Jwt<Header, Payload>): KeyBinding<Header, Payload>;
    /**
     *
     * Verify the jwt as a valid `KeyBinding` jwt.
     *
     * Invalid when:
     *   - The required claims for key binding are not included
     *   - The signature is invalid
     *   - The optional required additional claims are not included
     *
     */
    verify(verifySignature: Verifier<Header>, requiredClaims?: Array<keyof Payload | string>, publicKeyJwk?: Record<string, unknown>): Promise<KeyBindingVerificationResult>;
    /**
     *
     * Convert a compact `JWT` into an instance of `KeyBinding`.
     *
     * @throws when the claims are not valid for key binding
     *
     */
    static fromCompact<Header extends Record<string, unknown> = Record<string, unknown>, Payload extends Record<string, unknown> = Record<string, unknown>>(compact: string): ReturnKeyBindingWithHeaderAndPayload<Header, Payload, KeyBinding<Header, Payload>>;
    /**
     *
     * Asserts the required properties for valid key binding.
     *
     * @throws when a claim in the header, or payload, is invalid
     *
     */
    assertValidForKeyBinding(): Promise<void>;
}
export {};
