"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeyBinding = void 0;
const decode_1 = require("@sd-jwt/decode");
const jwt_1 = require("../jwt");
class KeyBinding extends jwt_1.Jwt {
    constructor(options, additionalOptions) {
        super(options);
        this.signer = additionalOptions === null || additionalOptions === void 0 ? void 0 : additionalOptions.signer;
    }
    /**
     *
     * Convert a standard `JWT` to an instance of `KeyBinding`.
     *
     * @throws when the claims are not valid for key binding
     *
     */
    static fromJwt(jwt) {
        const keyBinding = new KeyBinding({
            header: jwt.header,
            payload: jwt.payload,
            signature: jwt.signature
        }, { signer: jwt.signer });
        keyBinding.assertValidForKeyBinding();
        return keyBinding;
    }
    /**
     *
     * Verify the jwt as a valid `KeyBinding` jwt.
     *
     * Invalid when:
     *   - The required claims for key binding are not included
     *   - The signature is invalid
     *   - The optional required additional claims are not included
     *
     */
    verify(verifySignature, requiredClaims, publicKeyJwk) {
        const _super = Object.create(null, {
            verify: { get: () => super.verify }
        });
        return __awaiter(this, void 0, void 0, function* () {
            this.assertValidForKeyBinding();
            const jwtVerificationResult = yield _super.verify.call(this, verifySignature, requiredClaims, publicKeyJwk);
            return jwtVerificationResult;
        });
    }
    /**
     *
     * Convert a compact `JWT` into an instance of `KeyBinding`.
     *
     * @throws when the claims are not valid for key binding
     *
     */
    static fromCompact(compact) {
        const { header, payload, signature } = (0, decode_1.keyBindingFromCompact)(compact);
        const keyBinding = new KeyBinding({ header, payload, signature });
        return keyBinding;
    }
    /**
     *
     * Asserts the required properties for valid key binding.
     *
     * @throws when a claim in the header, or payload, is invalid
     *
     */
    assertValidForKeyBinding() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                this.assertHeader();
                this.assertPayload();
                if (!this.signature) {
                    yield this.signAndAdd();
                }
                this.assertSignature();
                this.assertClaimInHeader('typ', 'kb+jwt');
                this.assertClaimInHeader('alg');
                this.assertClaimInPayload('iat');
                this.assertClaimInPayload('nonce');
                this.assertClaimInPayload('aud');
            }
            catch (e) {
                if (e instanceof Error) {
                    e.message = `jwt is not valid for usage with key binding. Error: ${e.message}`;
                }
                throw e;
            }
        });
    }
}
exports.KeyBinding = KeyBinding;
//# sourceMappingURL=keyBinding.js.map