import { DisclosureItem, Hasher } from '../types';
export type DisclosureWithDigest = Disclosure & {
    digest: string;
};
export declare class Disclosure {
    #private;
    private salt;
    private key?;
    private value;
    constructor(salt: string, value: unknown, key?: string);
    static fromString(s: string): Disclosure;
    static fromArray(item: DisclosureItem): Disclosure;
    get encoded(): string;
    get decoded(): DisclosureItem;
    get digest(): string | undefined;
    /**
     * Set the digest of the disclosure.
     *
     * NOTE: this method statically sets the digest, and does not verify whether the digest is correct.
     * If you want to calculate the digest, use the `withCalculateDigest` method instead.
     */
    withDigest(digest: string): DisclosureWithDigest;
    withCalculateDigest<HasherImplementation extends Hasher>(hasher: HasherImplementation, { recalculate }?: {
        recalculate?: boolean;
    }): WithCalculateDigestReturnType<HasherImplementation>;
    toString(): string;
}
export type WithCalculateDigestReturnType<HasherImplementation extends Hasher> = ReturnType<HasherImplementation> extends Promise<any> ? Promise<DisclosureWithDigest> : DisclosureWithDigest;
export declare function isDisclosureWithDigest(disclosure: Disclosure): disclosure is DisclosureWithDigest;
